from django.apps import AppConfig


class TomNonlocalizedEventsConfig(AppConfig):
    name = 'tom_nonlocalizedevents'
